from .items import view_widget
from .base import (visualize_patches, webcam_widget, plot_graph,
                   save_matplotlib_figure, visualize_patch_appearance_model,
                   visualize_images, visualize_shapes_2d, visualize_shapes_3d,
                   visualize_landmarks_2d, visualize_landmarks_3d,
                   visualize_shape_model_2d, visualize_appearance_model,
                   visualize_meshes_3d, save_mayavi_figure,
                   visualize_shape_model_3d, visualize_morphable_model)
from .menpofitwidgets import *

from ._version import get_versions
__version__ = get_versions()['version']
del get_versions



from menpo.base import MenpoMissingDependencyError

try:
    from .base import (visualize_aam, visualize_patch_aam, visualize_atm,
                       visualize_patch_atm, visualize_clm,
                       visualize_expert_ensemble, plot_ced,
                       visualize_fitting_results)
except MenpoMissingDependencyError:
    pass


# Remove from scope
del MenpoMissingDependencyError
